%% Hierarchical Individual Search Orders
clear;

run_model=0; % set 0 to load samples, or 1 to run WinBUGS

%% Load Data
load DecisionData_1 y m p cv ds
% y is 20x100 binary decision data for simulated subjects by problems
% m is 83x9 stimulus by cue matrix defining German cities
% p is a 100x2 problem matrix, giving the city numbers for all 100 questions
% cv is 9x1 vector of cue validities
% ds is 9x1 vector of cue discriminabilities

% Constants
[n nc]=size(m); % number of stimuli and cues
[nq junk]=size(p); % number of questions
[ns junk]=size(y); % number of subjects


%% WinBUGS
% WinBUGS Sampling Parameters
nchains=2; 
nburnin=1e2;
nsamples=1e3; 

% Data to Supply to WinBugs
datastruct = struct('ns',ns,'nc',nc,'nq',nq,'m',m,'p',p,'y',y,'cv',cv,'ds',ds);

% Initial Values to Supply to WinBugs
for i=1:nchains
    S.gamma = 0.75; 
    S.muw = 0.5;
    S.sigmaw = 0.05;
	init0(i) = S;
end

if ~run_model
    load Search_2 samples stats
else
    % Use WinBUGS to Sample
[samples, stats] = matbugs(datastruct, ...
    fullfile(pwd, 'Search_2.txt'), ...
    'init', init0, ...
    'nChains', nchains, ...
    'view', 1, 'nburnin', nburnin, 'nsamples', nsamples, ...
    'thin', 1, 'DICstatus', 0, 'refreshrate',1, ...
    'monitorParams', {'gamma','s','t','w','muw','sigmaw'}, ...
    'Bugdir', 'C:/Program Files/WinBUGS14');
save Search_2 samples stats
end;

%% Analysis
% TTB Answers on 0-1 Scale
ttb_answers=zeros(ns,nq);
for i=1:ns
    for j=1:nq
        ttb_answers(i,j)=mode(reshape(samples.t(:,:,i,j),1,[]));
    end;
end;
ttb_answers=round((ttb_answers-1)/2);
% Proportion Correct
correct=sum(sum(ttb_answers==y))/ns/nq;
% Plot
figure(3);clf;hold on;
set(gcf,'units','norm','pos',[.2 .2 .6 .5],'paperpositionmode','auto');
axis([0 nq+1 0 ns+1]);
for i=1:nq
    for j=1:ns
        if y(j,i)==0
            ph=plot(i,j,'k+');
        end;
        if ttb_answers(j,i)==0
            ph=plot(i,j,'kx');
            set(ph,'markersize',8);
        end;
    end;
end;
set(gca,'fontsize',14,'box','on','ticklength',[0 0],'xtick',[1 12 20:10:90 96]);
xlabel('Question','fontsize',16);
ylabel('Subject','fontsize',16);
% Post Process Individual Search Orders
for sj=1:ns
    % Beginning analysis of the search order posterior
t=[squeeze(samples.s(1,:,sj,:));squeeze(samples.s(2,:,sj,:))];
%sc=squeeze(samples.sc(:,:,sj));

% What search orders are there in the posterior?
ut=unique(t,'rows');
[nut junk]=size(ut);

% What's the estimated mass of each, and how accurate is it?
for i=1:nut
    tmp=strmatch(ut(i,:),t);
    match(i)=length(tmp);
    %pc(i)=sc(tmp(1));
end;

% Sort 
[val ind]=sort(-match);
match=match(ind);
ut=ut(ind,:);
%pc=pc(ind);

% Display results
showorders=nut; % set to nut to display all orders
disp(sprintf('::\nSubject %d\nThere are %d search orders sampled in the posterior.',sj,nut));
for i=1:showorders
    [val ind]=sort(ut(i,:),'descend');
 disp(sprintf('Order=(%s), Estimated Mass=%1.4f',...
     int2str(ind),match(i)/sum(match)));
end;
clear ut match
end;